@@ -28,18 +28,18 @@ class Mode(Enum):
 
 
 def uri_connect(host: str = 'localhost', port: int = 27017, replicaset: str = None,
-                user: str = None, password: str = None, mode: Mode = None,
-                cert_key_file: str = None, ca_file: str = None, session_token: str = None) -> MongoClient:
+                user: str = None, password: str = None, cert_key_file: str = None,
+                ca_file: str = None, session_token: str = None, mode: Mode = Mode.AUTO) -> MongoClient:
     """ Connect with the database using different URI authentication methods.
     :param host: The database connection host.
     :param port: The database connection port.
     :param replicaset: The replicaset. If None, then, replicaset is not used.
     :param user: The MongoDB username, access key id or session token. If None, then, username is used.
     :param password: The MongoDB password or secret access key. If None, then, password is used.
-    :param mode: The authentication mode. By default, the URL mode is used.
     :param cert_key_file: The path to the certificate key file.
     :param ca_file: The path to the CA file.
     :param session_token: The session token to use.
+    :param mode: The authentication mode. By default, the URL mode is used.
     :return: The MongoDB client.
     """
     if mode == Mode.AUTO:
@@ -95,8 +95,8 @@ def auth_connect(host: str = 'localhost', port: int = 27017, replicaset: str = N
 
 
 def connect(host: str = 'localhost', port: int = 27017, replicaset: str = None,
-            user: str = None, password: str = None, mode: Mode = Mode.AUTO,
-            cert_key_file: str = None, ca_file: str = None, session_token: str = None) -> MongoClient:
+            user: str = None, password: str = None, cert_key_file: str = None, ca_file: str = None,
+            session_token: str = None, mode: Mode = Mode.AUTO) -> MongoClient:
     """ Connect with the database.
     :param host: The database connection host.
     :param port: The database connection port.
@@ -114,10 +114,10 @@ def connect(host: str = 'localhost', port: int = 27017, replicaset: str = None,
     if mode == Mode.AUTO:
         return detect_connection(host, port, replicaset, user, password, cert_key_file, ca_file, session_token)
     if mode in [Mode.MONGODB_X509, Mode.GSSAPI]:
-        return uri_connect(host, port, replicaset, user, None, mode, cert_key_file, ca_file, session_token)
+        return uri_connect(host, port, replicaset, user, None, cert_key_file, ca_file, session_token, mode)
     if mode in [Mode.SCRAM_SHA_256, Mode.SCRAM_SHA_1]:
         return auth_connect(host, port, replicaset, user, password, mode)
-    return uri_connect(host, port, replicaset, user, password, mode, cert_key_file, ca_file, session_token)
+    return uri_connect(host, port, replicaset, user, password, cert_key_file, ca_file, session_token, mode)
 
 
 def connect_database(host: str = 'localhost', port: int = 27017, replicaset: str = None, database: str = None,
@@ -136,7 +136,7 @@ def connect_database(host: str = 'localhost', port: int = 27017, replicaset: str
     :param session_token: The session token to use.
     :return: The MongoDB client.
     """
-    client = connect(host, port, replicaset, user, password, mode, cert_key_file, ca_file, session_token)
+    client = connect(host, port, replicaset, user, password, cert_key_file, ca_file, session_token, mode)
     db = client[database]
     db.list_collection_names()
     return db
@@ -158,7 +158,7 @@ def detect_connection(host: str = 'localhost', port: int = 27017, replicaset: st
     """
     for mode in list(Mode)[2:]:
         try:
-            client = connect(host, port, replicaset, user, password, mode, cert_key_file, ca_file, session_token)
+            client = connect(host, port, replicaset, user, password, cert_key_file, ca_file, session_token, mode)
             client.list_database_names()
             return client
         except (ServerSelectionTimeoutError, OperationFailure):
